from neofs_testlib.shell.interfaces import CommandOptions, CommandResult, InteractiveInput, Shell
from neofs_testlib.shell.local_shell import LocalShell
from neofs_testlib.shell.ssh_shell import SSHShell
